<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>KeyboardConfig</name>
    <message>
        <location filename="../keyboardconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="20"/>
        <source>Cursor flash time:</source>
        <translation>Честота на примигване на курсора:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="27"/>
        <source>&lt;b&gt;Keyboard&lt;/b&gt;</source>
        <translation>&lt;b&gt;Клавиатура&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="34"/>
        <source>Beep when there is an error of keyboard input</source>
        <translation>Звуков сигнал, когато има грешка при въвеждане на клавиатурата</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="41"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="51"/>
        <source>Character Repeat</source>
        <translation>Повторение на знаци</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="79"/>
        <location filename="../keyboardconfig.ui" line="143"/>
        <source>Long</source>
        <translation>Дълго</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="108"/>
        <source>Repeat delay:</source>
        <translation>Повторно закъснение:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="115"/>
        <location filename="../keyboardconfig.ui" line="136"/>
        <source>Short</source>
        <translation>Кратко</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="122"/>
        <source>Repeat interval:</source>
        <translation>Повтори интервал:</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="129"/>
        <source>Type in the following box to test your keyboard settings</source>
        <translation>Пишете в следната кутия, за да тествате клавиатурните настройки</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="150"/>
        <location filename="../keyboardconfig.ui" line="157"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../keyboardconfig.ui" line="167"/>
        <source>Turn on NumLock after login</source>
        <translation>Включване на Num Lock след вход в системата</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutConfig</name>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="20"/>
        <source>&lt;b&gt;Keyboard Layout&lt;/b&gt;</source>
        <translation>&lt;b&gt;Клавиатурна подредба&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="48"/>
        <source>Layout</source>
        <translation>Подредба</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="53"/>
        <source>Variant</source>
        <translation>Вариант</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="63"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавяне</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="70"/>
        <source>&amp;Remove</source>
        <translation>&amp;Премахване</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="77"/>
        <source>Up</source>
        <translation>Нагоре</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="84"/>
        <source>Down</source>
        <translation>Надолу</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="108"/>
        <source>Keyboard model:</source>
        <translation>Модел на клавиатурата:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="122"/>
        <source>Keys to change layout:</source>
        <translation>Клавиши за смяна на подредбата:</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="133"/>
        <source>None</source>
        <translation>Няма</translation>
    </message>
    <message>
        <location filename="../keyboardlayoutconfig.ui" line="141"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note&lt;/span&gt;: If you are using an &lt;span style=&quot; font-weight:600;&quot;&gt;input method&lt;/span&gt;, such as IBus, uim, fcitx, or gcin, the settings here &lt;span style=&quot; font-weight:600;&quot;&gt;might not work&lt;/span&gt; because they are overridden by the input methods.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Забележка&lt;/span&gt;: Ако използвате &lt;span style=&quot; font-weight:600;&quot;&gt;метод на въвеждане&lt;/span&gt;, като IBus, uim, fcitx или gcin, настройките тук &lt;span style=&quot; font-weight:600;&quot;&gt;може да не работят&lt;/span&gt;, защото са презаписани от този метод на въвеждане.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
</context>
<context>
    <name>MouseConfig</name>
    <message>
        <location filename="../mouseconfig.ui" line="14"/>
        <source>Form</source>
        <translation>Форма</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="23"/>
        <source>&lt;b&gt;Mouse&lt;/b&gt;</source>
        <translation>&lt;b&gt;Мишка&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="30"/>
        <source>Motion</source>
        <translation>Движение</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="36"/>
        <source>High</source>
        <translation>Високо</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="43"/>
        <source>Fast</source>
        <translation>Бързо</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="50"/>
        <source>Sensitivity:</source>
        <translation>Чувствителност:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="57"/>
        <source>Low</source>
        <translation>Ниско</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="83"/>
        <source>Acceleration:</source>
        <translation>Ускорение:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="109"/>
        <source>Slow</source>
        <translation>Бавно</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="116"/>
        <location filename="../mouseconfig.ui" line="123"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="133"/>
        <source>Double click interval:</source>
        <translation>Интерван на двойния клик:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="140"/>
        <source> ms</source>
        <translation> мс</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="150"/>
        <source>Wheel scroll lines:</source>
        <translation>Линии на скрола за превъртане:</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="160"/>
        <source>Left handed (Swap left and right mouse buttons)</source>
        <translation>Лява ръка (смяна на ляв и десен бутони на мишката)</translation>
    </message>
    <message>
        <location filename="../mouseconfig.ui" line="167"/>
        <source>Single click to activate items</source>
        <translation>Един клик за активиране на елементи</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqt-config-input.cpp" line="70"/>
        <source>Keyboard and Mouse Settings</source>
        <translation>Настройки на клавиатурата и мишката</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="79"/>
        <source>Mouse</source>
        <translation>Мишка</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="88"/>
        <source>Cursor</source>
        <translation>Курсор</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="95"/>
        <source>Keyboard</source>
        <translation>Клавиатура</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="103"/>
        <source>Keyboard Layout</source>
        <translation>Клавиатурна подредба</translation>
    </message>
    <message>
        <location filename="../lxqt-config-input.cpp" line="112"/>
        <source>Mouse and Touchpad</source>
        <translation>Мишка и тъчпад</translation>
    </message>
</context>
<context>
    <name>SelectKeyboardLayoutDialog</name>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="14"/>
        <source>Select a keyboard layout</source>
        <translation>Избиране на клавиатурна подредба</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="20"/>
        <source>Keyboard layout</source>
        <translation>Клавиатурна подредба</translation>
    </message>
    <message>
        <location filename="../selectkeyboardlayoutdialog.ui" line="27"/>
        <source>Variant</source>
        <translation>Вариант</translation>
    </message>
</context>
<context>
    <name>TouchpadConfig</name>
    <message>
        <location filename="../touchpadconfig.ui" line="14"/>
        <source>TouchpadConfig </source>
        <translation>Конфигуриране на тъчпада </translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="20"/>
        <source>Device:</source>
        <translation>Устройство:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="30"/>
        <source>Acceleration speed:</source>
        <translation>Скорост на ускорение:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="37"/>
        <source>Tap to click</source>
        <translation>Докоснете, за да щракнете</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="44"/>
        <source>Natural Scrolling</source>
        <translation>Естествено превъртане</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="51"/>
        <source>Tap and drag</source>
        <translation>Чукнете и плъзнете</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="79"/>
        <source>Scrolling:</source>
        <translation>Превъртане:</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="102"/>
        <source>&amp;Disabled</source>
        <translation>&amp;Изключен</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="109"/>
        <source>&amp;Two-Finger</source>
        <translation>&amp;С два пръста</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="116"/>
        <source>Ed&amp;ge</source>
        <translation>Ръб, край</translation>
    </message>
    <message>
        <location filename="../touchpadconfig.ui" line="123"/>
        <source>B&amp;utton</source>
        <translation>б&amp;утон</translation>
    </message>
</context>
</TS>
